<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for VersionId StructType
 * Meta information extracted from the WSDL
 * - documentation: Identifies the version/level of a service operation expected by a caller (in each request) and performed by the callee (in each reply).
 * @subpackage Structs
 */
class VersionId extends AbstractStructBase
{
    /**
     * The ServiceId
     * Meta information extracted from the WSDL
     * - documentation: Identifies a system or sub-system which performs an operation.
     * - fixed: cdus
     * - minOccurs: 1
     * @var string
     */
    public $ServiceId;
    /**
     * The Major
     * Meta information extracted from the WSDL
     * - documentation: Identifies the service business level.
     * - fixed: 8
     * - minOccurs: 1
     * @var int
     */
    public $Major;
    /**
     * The Intermediate
     * Meta information extracted from the WSDL
     * - documentation: Identifies the service interface level.
     * - fixed: 0
     * - minOccurs: 1
     * @var int
     */
    public $Intermediate;
    /**
     * The Minor
     * Meta information extracted from the WSDL
     * - documentation: Identifies the service code level.
     * - fixed: 0
     * - minOccurs: 1
     * @var int
     */
    public $Minor;
    /**
     * Constructor method for VersionId
     * @uses VersionId::setServiceId()
     * @uses VersionId::setMajor()
     * @uses VersionId::setIntermediate()
     * @uses VersionId::setMinor()
     * @param string $serviceId
     * @param int $major
     * @param int $intermediate
     * @param int $minor
     */
    public function __construct($serviceId = null, $major = null, $intermediate = null, $minor = null)
    {
        $this
            ->setServiceId($serviceId)
            ->setMajor($major)
            ->setIntermediate($intermediate)
            ->setMinor($minor);
    }
    /**
     * Get ServiceId value
     * @return string
     */
    public function getServiceId()
    {
        return $this->ServiceId;
    }
    /**
     * Set ServiceId value
     * @param string $serviceId
     * @return \StructType\VersionId
     */
    public function setServiceId($serviceId = null)
    {
        // validation for constraint: string
        if (!is_null($serviceId) && !is_string($serviceId)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($serviceId, true), gettype($serviceId)), __LINE__);
        }
        $this->ServiceId = $serviceId;
        return $this;
    }
    /**
     * Get Major value
     * @return int
     */
    public function getMajor()
    {
        return $this->Major;
    }
    /**
     * Set Major value
     * @param int $major
     * @return \StructType\VersionId
     */
    public function setMajor($major = null)
    {
        // validation for constraint: int
        if (!is_null($major) && !(is_int($major) || ctype_digit($major))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($major, true), gettype($major)), __LINE__);
        }
        $this->Major = $major;
        return $this;
    }
    /**
     * Get Intermediate value
     * @return int
     */
    public function getIntermediate()
    {
        return $this->Intermediate;
    }
    /**
     * Set Intermediate value
     * @param int $intermediate
     * @return \StructType\VersionId
     */
    public function setIntermediate($intermediate = null)
    {
        // validation for constraint: int
        if (!is_null($intermediate) && !(is_int($intermediate) || ctype_digit($intermediate))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($intermediate, true), gettype($intermediate)), __LINE__);
        }
        $this->Intermediate = $intermediate;
        return $this;
    }
    /**
     * Get Minor value
     * @return int
     */
    public function getMinor()
    {
        return $this->Minor;
    }
    /**
     * Set Minor value
     * @param int $minor
     * @return \StructType\VersionId
     */
    public function setMinor($minor = null)
    {
        // validation for constraint: int
        if (!is_null($minor) && !(is_int($minor) || ctype_digit($minor))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($minor, true), gettype($minor)), __LINE__);
        }
        $this->Minor = $minor;
        return $this;
    }
}
